==> Appium-Python-Client-2.6.0.tar.gz: Appium-Python-Client-2.6.0/appium/options/ios/xcuitest/app/app_push_timeout_option.py <==
# Licensed to the Software Freedom Conservancy (SFC) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The SFC licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from datetime import timedelta
from typing import Optional, Union

from appium.options.common.supports_capabilities import SupportsCapabilities

APP_PUSH_TIMEOUT = 'appPushTimeout'


class AppPushTimeoutOption(SupportsCapabilities):
    @property
    def app_push_timeout(self) -> Optional[timedelta]:
        """
        Maximum timeout for application upload.
        """
        value = self.get_capability(APP_PUSH_TIMEOUT)
        return None if value is None else timedelta(milliseconds=value)

    @app_push_timeout.setter
    def app_push_timeout(self, value: Union[timedelta, int]) -> None:
        """
        The timeout for application upload.
        Works for real devices only.
        The default value is 30000ms.
        """
        self.set_capability(APP_PUSH_TIMEOUT, value.microseconds // 1000 if isinstance(value, timedelta) else value)

==> Appium-Python-Client-2.10.1.tar.gz: Appium-Python-Client-2.10.1/appium/options/ios/xcuitest/app/app_push_timeout_option.py <==
# Licensed to the Software Freedom Conservancy (SFC) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The SFC licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from datetime import timedelta
from typing import Optional, Union

from appium.options.common.supports_capabilities import SupportsCapabilities

APP_PUSH_TIMEOUT = 'appPushTimeout'


class AppPushTimeoutOption(SupportsCapabilities):
    @property
    def app_push_timeout(self) -> Optional[timedelta]:
        """
        Maximum timeout for application upload.
        """
        value = self.get_capability(APP_PUSH_TIMEOUT)
        return None if value is None else timedelta(milliseconds=value)

    @app_push_timeout.setter
    def app_push_timeout(self, value: Union[timedelta, int]) -> None:
        """
        The timeout for application upload.
        Works for real devices only.
        The default value is 30000ms.
        """
        self.set_capability(
            APP_PUSH_TIMEOUT, int(value.total_seconds() * 1000) if isinstance(value, timedelta) else value
        )
